@@ -32,6 +32,10 @@ MONGO_USER = None
 MONGO_PWD = None
 MONGO_CONFIG = {}  # 字典形式
 
+'''KAFKA'''
+KAFKA_SERVER = None
+KAFKA_CONFIG = {}  # 字典形式
+
 '''REDIS'''
 REDIS_DB = 0
 REDIS_HOST = None
@@ -58,7 +62,7 @@ REQUEST_FILTER = False  # 去重请求，开启了，请求时的 filter_repeat
 PERSISTENCE_REQUEST_FILTER = False  # 是否持久化请求过滤（分布式时才有效，否则每次结束都会清除）
 REQUEST_DELAY = 0  # 请求间隔
 REQUEST_RETRY_TIMES = 3  # 请求失败重试次数
-REQUEST_TIMEOUT = 10  # 请求超时时间，也可以是元组 (connect timeout, read timeout)
+REQUEST_TIMEOUT = 30  # 请求超时时间，也可以是元组 (connect timeout, read timeout)
 RANDOM_USERAGENT = False  # 随机请求头（默认是 computer，指定则开启下面的选项）
 RANDOM_USERAGENT_TYPE = 'computer'  # UA 类型：电脑（computer 代表电脑内随便选，后面代表指定浏览器 chrome、opera、firefox、ie、safari）手机：mobile
 DEFAULT_USER_AGENT = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36 Edg/107.0.1418.35'
@@ -69,10 +73,14 @@ REQUEST_MIDDLEWARE = [
     "palp.middleware.middleware_request_base.BaseRequestMiddleware",
 ]
 
-# palp 必须的请求中间件，用户定义
-PALP_REQUEST_MIDDLEWARE = [
+# palp 必须的请求中间件，非用户定义
+# first
+PALP_FIRST_REQUEST_MIDDLEWARE = [
     "palp.middleware.middleware_request_check.RequestCheckMiddleware",
 ]
+# last
+PALP_LAST_REQUEST_MIDDLEWARE = [
+]
 
 # 请求队列
 REQUEST_MODE = 1  # 1 为先进先出队列，2 为后进先出队列，3 为优先级队列
@@ -136,6 +144,13 @@ SPIDER_MIDDLEWARE = [
     'palp.middleware.middleware_spider_base.BaseSpiderMiddleware',
 ]
 
+# palp 必须的请求中间件，非用户定义
+PALP_FIRST_SPIDER_MIDDLEWARE = [
+]
+PALP_LAST_SPIDER_MIDDLEWARE = [
+    'palp.middleware.middleware_spider_recycle.SpiderRecycleMiddleware',
+]
+
 # 爬虫本身配置
 SPIDER_THREAD_COUNT = 16  # spider 默认的线程数量
 
