@@ -35,6 +35,10 @@ BASE_PATH = Path(__file__).absolute().parent
 # MONGO_PWD = None
 # MONGO_CONFIG = {}  # 字典形式
 
+'''KAFKA'''
+# KAFKA_SERVER = None
+# KAFKA_CONFIG = {}  # 字典形式
+
 '''REDIS'''
 # REDIS_DB = 0
 # REDIS_HOST = None
@@ -50,7 +54,7 @@ BASE_PATH = Path(__file__).absolute().parent
 # PERSISTENCE_REQUEST_FILTER = False  # 是否持久化请求过滤（分布式时才有效，否则每次结束都会清除）
 # REQUEST_DELAY = 0  # 请求间隔
 # REQUEST_RETRY_TIMES = 3  # 请求失败重试次数
-# REQUEST_TIMEOUT = 10  # 请求超时时间，也可以是元组 (connect timeout, read timeout)
+# REQUEST_TIMEOUT = 30  # 请求超时时间，也可以是元组 (connect timeout, read timeout)
 # RANDOM_USERAGENT = False  # 随机请求头（默认是 computer，指定则开启下面的选项）
 # RANDOM_USERAGENT_TYPE = 'computer'  # UA 类型：电脑（computer 代表电脑内随便选，后面代表指定浏览器 chrome、opera、firefox、ie、safari）手机：mobile
 # DEFAULT_USER_AGENT = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36 Edg/107.0.1418.35'
